@@ -1,13 +1,11 @@
-from __future__ import unicode_literals
-
-import six
 import uuid
 
 from django.db import models
+from django.utils.timezone import now
+
 from smartmin.models import SmartModel, ActiveManager
 
 
-@six.python_2_unicode_compatible
 class Post(SmartModel):
     title = models.CharField(max_length=128,
                              help_text="The title of this blog post, keep it relevant")
@@ -16,7 +14,12 @@ class Post(SmartModel):
     tags = models.CharField(max_length=128,
                             help_text="Any tags for this post")
 
-    uuid = models.CharField(max_length=36, default=uuid.uuid4, editable=False)  # UUID field only added in Django 1.8
+    uuid = models.UUIDField(default=uuid.uuid4, editable=False)
+
+    written_on = models.DateField(default=now, null=True, blank=True)
+
+    image = models.ImageField(upload_to="images", null=True, blank=True,
+                              help_text="The logo that should be used for this post")
 
     objects = models.Manager()
     active = ActiveManager()
@@ -36,6 +39,10 @@ class Post(SmartModel):
         if 'title' not in header:
             raise Exception('missing "title" header')
 
+    @classmethod
+    def finalize_import(cls, task, records):
+        Post.objects.filter(id__in=[p.id for p in records]).update(tags="new")
+
     def __str__(self):
         return self.title
 
